angular.module('focaModalVendedores')
    .controller('modalVendedoresCtrl', [
        '$timeout',
        '$filter',
        '$scope',
        '$uibModalInstance',
        'focaVendedoresService',
        function($timeout, $filter, $scope, $uibModalInstance, focaVendedoresService) {

            $scope.filters = '';
            $scope.vendedores = [];
            $scope.primerBusqueda = false;
            $scope.searchLoading = false;
            // pagination
            $scope.numPerPage = 10;
            $scope.currentPage = 1;
            $scope.filteredVendedores = [];
            $scope.currentPageVendedores = [];
            $scope.selectedVendedor = -1;

            $scope.busquedaPress = function(key) {
                if (key === 13) {
                    $scope.searchLoading = true;
                    focaVendedoresService.getVendedores($scope.filters).then(
                        function(res) {
                            $scope.searchLoading = false;
                            $scope.primerBusqueda = true;
                            $scope.vendedores = res.data;
                            $scope.search(true);
                            primera();
                        }
                    );
                }
            };

            $scope.search = function(pressed) {
                if($scope.vendedores.length > 0) {
                    $scope.filteredVendedores = $filter('filter')(
                        $scope.vendedores, { $: $scope.filters }
                    );

                    $scope.lastPage = Math.ceil(
                        $scope.filteredVendedores.length / $scope.numPerPage
                    );
                    $scope.resetPage();
                }else if(pressed){
                    $timeout(function() {
                        angular.element('#search')[0].focus();
                        $scope.filters = '';
                    });
                }
            };

            $scope.resetPage = function() {
                $scope.currentPage = 1;
                $scope.selectPage(1);
            };

            $scope.selectPage = function(page) {
                var start = (page - 1) * $scope.numPerPage;
                var end = start + $scope.numPerPage;
                $scope.paginas = [];
                $scope.paginas = calcularPages(page);
                $scope.currentPageVendedores = $scope.filteredVendedores.slice(start, end);
                $scope.currentPage = page;
            };

            $scope.select = function(vendedor) {
                $uibModalInstance.close(vendedor);
            };

            $scope.cancel = function() {
                $uibModalInstance.dismiss('cancel');
            };

            $scope.busquedaDown = function(key) {
                if (key === 40) {
                    primera(key);
                }
            };

            $scope.itemVendedor = function(key) {
                if (key === 38) {
                    anterior(key);
                }

                if (key === 40) {
                    siguiente(key);
                }

                if (key === 37) {
                    retrocederPagina();
                }

                if (key === 39) {
                    avanzarPagina();
                }
            };

            function calcularPages(paginaActual) {
                var paginas = [];
                paginas.push(paginaActual);

                if (paginaActual - 1 > 1) {

                    paginas.unshift(paginaActual - 1);
                    if (paginaActual - 2 > 1) {
                        paginas.unshift(paginaActual - 2);
                    }
                }

                if (paginaActual + 1 < $scope.lastPage) {
                    paginas.push(paginaActual + 1);
                    if (paginaActual + 2 < $scope.lastPage) {
                        paginas.push(paginaActual + 2);
                    }
                }

                if (paginaActual !== 1) {
                    paginas.unshift(1);
                }

                if (paginaActual !== $scope.lastPage) {
                    paginas.push($scope.lastPage);
                }

                return paginas;
            }

            function primera() {
                $scope.selectedVendedor = 0;
            }

            function anterior() {
                if ($scope.selectedVendedor === 0 && $scope.currentPage > 1) {
                    retrocederPagina();
                } else {
                    $scope.selectedVendedor--;
                }
            }

            function siguiente() {
                if ($scope.selectedVendedor < $scope.currentPageVendedores.length - 1) {
                    $scope.selectedVendedor++;
                } else {
                    avanzarPagina();
                }
            }

            function retrocederPagina() {
                if ($scope.currentPage > 1) {
                    $scope.selectPage($scope.currentPage - 1);
                    $scope.selectedVendedor = $scope.numPerPage - 1;
                }
            }

            function avanzarPagina() {
                if ($scope.currentPage < $scope.lastPage) {
                    $scope.selectPage($scope.currentPage + 1);
                    $scope.selectedVendedor = 0;
                }
            }
        }]
    );
